@@ -104,12 +104,8 @@ purge_shared_alert_mem()
 {
 	int		i;
 
-#if PG_VERSION_NUM >= 90600
-
 	LWLockAcquire(ProcArrayLock, LW_SHARED);
 
-#endif
-
 	for (i = 0; i < MAX_LOCKS; i++)
 	{
 		PGPROC	   *proc;
@@ -117,16 +113,8 @@ purge_shared_alert_mem()
 		if (locks[i].sid == NOT_USED)
 			continue;
 
-#if PG_VERSION_NUM < 90600
-
-		proc = BackendPidGetProc(locks[i].pid);
-
-#else
-
 		proc = BackendPidGetProcWithLock(locks[i].pid);
 
-#endif
-
 		if (proc == NULL)
 		{
 			int		j;
@@ -146,12 +134,7 @@ purge_shared_alert_mem()
 		}
 	}
 
-#if PG_VERSION_NUM >= 90600
-
 	LWLockRelease(ProcArrayLock);
-
-#endif
-
 }
 
 /*
