@@ -13,6 +13,11 @@
 
 #include "stdint.h"
 
+#if PG_VERSION_NUM >= 160000
+
+#include "varatt.h"
+
+#endif
 
 #define LIST_ITEMS  512
 
